(function ($) {
  var timestamps;
  var timestampsPerPage = 10;
  var loadedTimestamps = 0;

  var $container;
  var $loadOlderResults = $('<p><a href="javascript: void(0);">Load older results</a></p>');

  function loadResults(start, end, callback) {
    var lastDate = 0;
    var rowNumber = 0;

    var $row, $card, $date, $goodCount, $badCount, $table;

    $.get('appltest/results.php', {start: start, end: end}, function (runs) {
      var i, run, date, dateString, $run;

      for (i=0; i<runs.length; ++i) {
        run = runs[i];

        // Check if new date
        date = moment(run.timestamp*1000);
        dateString = date.format('dddd, MMMM Do YYYY, HH:mm');

        if (date - lastDate) {
          // Reset row count
          rowNumber = 0;

          // New date display
          $card = $('<div class="card"><div class="card-header"></div></div>').appendTo($container);
          $date = $('<a href="javascript: void(0);">' + dateString + '</a>').appendTo($('.card-header', $card));
          $badCount = $('<span class="tag tag-danger pull-xs-right">0</span>').hide().appendTo($('.card-header', $card));
          $goodCount = $('<span class="tag tag-success pull-xs-right">0</span>').hide().appendTo($('.card-header', $card));

          $('.card-header', $card).append('&nbsp;<small class="text-muted">using applgrid ' + run.applgrid_version + ', mcfm_bridge ' + run.mcfmbridge_version + '</small>');

          // Runs table
          $table = $('<ul class="list-group list-group-flush collapse"/>').appendTo($card);

          if (!lastDate && !loadedTimestamps) {
            $table.addClass('in');
          }

          $date.on('click', function () {
            this.toggleClass('in');
          }.bind($table));

          // Remember current date
          lastDate = date;
        }

        // Add run to table
        $run = $('<li class="list-group-item"/>').appendTo($table);

        if (run.min_agreement > 0.0001) {
          $run.addClass('list-group-item-danger');
          $badCount.text(parseInt($badCount.text()) + 1).show();
        } else {
          $run.addClass('list-group-item-success');
          $goodCount.text(parseInt($goodCount.text()) + 1).show();
        }

        $run.append(run.process);
        $run.append('<span class="tag tag-default pull-xs-right">RMS <strong>' + run.min_rms.toExponential(0) + '</strong> to <strong>' + run.max_rms.toExponential(0) + '</strong></span>');
        $run.append('<span class="tag tag-default pull-xs-right">Agreement <a href="' + run.pdf_best + '" target="_blank">' + run.min_agreement.toExponential(0) + '</a> to <a href="' + run.pdf_worst + '" target="_blank">' + run.max_agreement.toExponential(0) + '</a></span>');
      }

      callback();
    }, 'json');
  }

  function paginate() {
    if (timestamps.length - loadedTimestamps > timestampsPerPage) {
      loadResults(timestamps[loadedTimestamps], timestamps[loadedTimestamps + timestampsPerPage - 1], function () {
        loadedTimestamps += timestampsPerPage;
        $container.append($loadOlderResults.show());
      });
    } else {
      loadResults(timestamps[loadedTimestamps], 0, function () {
        loadedTimestamps += timestampsPerPage;
      });
    }
  }

  $('a', $loadOlderResults).on('click', function () {
    $loadOlderResults.hide();
    paginate();
  });

  $(document).ready(function () {
    $container = $('#appltest');

    $.get('appltest/timestamps.php', function (json) {
      timestamps = json;
      paginate();
    }, 'json');
  });
})(jQuery);
