<?php
# Load processes
$lines = explode("\n", file_get_contents('process.DAT'));
$processes = [];
$pattern = '/^(\d+).* --> ([^\']+)\'.*/s';

foreach($lines as $line) {
  if (preg_match($pattern, $line, $match)) {
    $match[2] = preg_replace('/\(p\d+\)/', '', $match[2]);
    $match[2] = preg_replace('/([^\^])\+/', '$1 + ', $match[2]);
    $match[2] = str_replace('nu', '&nu;', $match[2]);
    $match[2] = str_replace('&nu;~', '<span style="text-decoration: overline;">&nu;</span>', $match[2]);
    $match[2] = preg_replace('/\^(.)/', '<sup>$1</sup>', $match[2]);
    $match[2] = preg_replace('/(.)~/', '<span style="text-decoration: overline;">$1</span>', $match[2]);
    $match[2] = str_replace('(-->', ' (&rarr; ', $match[2]);
    $processes[$match[1]] = '<strong>' . $match[1] . '</strong>: ' . $match[2];
  }
}

# Load results
$db = new SQLite3("../nightlies/results.db");

$query = "SELECT * FROM results";

if ($_GET["start"]) {
  $query .= " WHERE timestamp <= " . SQLite3::escapeString($_GET["start"]);

  if ($_GET["end"]) {
    $query .= " AND timestamp >= " . SQLite3::escapeString($_GET["end"]);
  }
}

$query .= " ORDER BY timestamp DESC, nproc ASC;";

$results = [];
$rows = $db->query($query);

while ($row = $rows->fetchArray(SQLITE3_ASSOC)) {
  $run = $row["timestamp"] . "-" . $row["test_name"];

  if (!$results[$run]) {
    $results[$run] = [
      "timestamp" => $row["timestamp"],
      "process" => $processes[$row["nproc"]] ? $processes[$row["nproc"]] : ("Unknown process '" . $row["nproc"] . "'"),
      "applgrid_version" => $row["applgrid_version"],
      "mcfmbridge_version" => $row["mcfmbridge_version"]
    ];
  }

  //array_push($results[$run]["processes"], $row);

  // Find best and worst rms and agreements
  if (!$results[$run]["min_rms"] || $results[$run]["min_rms"] > $row["rms"]) {
    $results[$run]["min_rms"] = $row["rms"];
  }

  if (!$results[$run]["max_rms"] || $results[$run]["max_rms"] < $row["rms"]) {
    $results[$run]["max_rms"] = $row["rms"];
  }

  if (!$results[$run]["min_agreement"] || $results[$run]["min_agreement"] > $row["agreement"]) {
    $results[$run]["min_agreement"] = $row["agreement"];
    $results[$run]["pdf_best"] = "appltest/ratio.php?result=" . $row["id"] . "&agreement=" . $row["agreement"];
  }

  if (!$results[$run]["max_agreement"] || $results[$run]["max_agreement"] < $row["agreement"]) {
    $results[$run]["max_agreement"] = $row["agreement"];
    $results[$run]["pdf_worst"] = "appltest/ratio.php?result=" . $row["id"] . "&agreement=" . $row["agreement"];
  }
}

$db->close();

echo json_encode(array_values($results));
